==> ejc-budgetmanage-impl-3.0.0-20220328.024439-27-sources.jar: com/ejianc/business/bedget/vo/EstimatesummaryVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordestimatesummaryVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.bedget.vo.EstimatesummarydetailVO;

/**
 * 设计概算汇总表
 * 
 * @author generator
 * 
 */
public class EstimatesummaryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long operatorId; // 经办人id
    private java.lang.String operatorName; // 经办人名称
    private java.math.BigDecimal budgetEstimateTotal; // 设计概算合计
    private java.math.BigDecimal engineeringTotal; // 建筑工程费合计
    private java.math.BigDecimal purchaseTotal; // 设备购置费合计
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    
    private List<EstimatesummarydetailVO> estimatesummarydetailEntities = new ArrayList<>(); // 设计概算汇总子表
    private List<RecordestimatesummaryVO> recordestimatesummaryVOList = new ArrayList<>(); // 设计概算汇总子表

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 设计概算合计
     */
    public java.math.BigDecimal getBudgetEstimateTotal() {
        return budgetEstimateTotal;
    }

    /**
     * 设计概算合计
     */
    public void setBudgetEstimateTotal(java.math.BigDecimal budgetEstimateTotal) {
        this.budgetEstimateTotal = budgetEstimateTotal;
    }
    /**
     * 建筑工程费合计
     */
    public java.math.BigDecimal getEngineeringTotal() {
        return engineeringTotal;
    }

    /**
     * 建筑工程费合计
     */
    public void setEngineeringTotal(java.math.BigDecimal engineeringTotal) {
        this.engineeringTotal = engineeringTotal;
    }
    /**
     * 设备购置费合计
     */
    public java.math.BigDecimal getPurchaseTotal() {
        return purchaseTotal;
    }

    /**
     * 设备购置费合计
     */
    public void setPurchaseTotal(java.math.BigDecimal purchaseTotal) {
        this.purchaseTotal = purchaseTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    
     /**
      * 设计概算汇总子表
      */
     public List<EstimatesummarydetailVO> getEstimatesummarydetailEntities() {
        return estimatesummarydetailEntities;
     }

     /**
      * 设计概算汇总子表
      */
     public void setEstimatesummarydetailEntities(List<EstimatesummarydetailVO> estimatesummarydetailEntities) {
        this.estimatesummarydetailEntities = estimatesummarydetailEntities;
     }

    public List<RecordestimatesummaryVO> getRecordestimatesummaryVOList() {
        return recordestimatesummaryVOList;
    }

    public void setRecordestimatesummaryVOList(List<RecordestimatesummaryVO> recordestimatesummaryVOList) {
        this.recordestimatesummaryVOList = recordestimatesummaryVOList;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20230324.091733-161-sources.jar: com/ejianc/business/bedget/vo/EstimatesummaryVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordestimatesummaryVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 设计概算汇总表
 * 
 * @author generator
 * 
 */
public class EstimatesummaryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long operatorId; // 经办人id
    private java.lang.String operatorName; // 经办人名称
    private java.math.BigDecimal budgetEstimateTotal; // 设计概算合计
    private java.math.BigDecimal engineeringTotal; // 建筑工程费合计
    private java.math.BigDecimal purchaseTotal; // 设备购置费合计
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更

    private java.lang.String sort;
    private java.lang.String createTimeShow;
    private java.lang.String billStateStr;
    
    private List<EstimatesummarydetailVO> estimatesummarydetailEntities = new ArrayList<>(); // 设计概算汇总子表
    private List<RecordestimatesummaryVO> recordestimatesummaryVOList = new ArrayList<>(); // 设计概算汇总子表

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 设计概算合计
     */
    public java.math.BigDecimal getBudgetEstimateTotal() {
        return budgetEstimateTotal;
    }

    /**
     * 设计概算合计
     */
    public void setBudgetEstimateTotal(java.math.BigDecimal budgetEstimateTotal) {
        this.budgetEstimateTotal = budgetEstimateTotal;
    }
    /**
     * 建筑工程费合计
     */
    public java.math.BigDecimal getEngineeringTotal() {
        return engineeringTotal;
    }

    /**
     * 建筑工程费合计
     */
    public void setEngineeringTotal(java.math.BigDecimal engineeringTotal) {
        this.engineeringTotal = engineeringTotal;
    }
    /**
     * 设备购置费合计
     */
    public java.math.BigDecimal getPurchaseTotal() {
        return purchaseTotal;
    }

    /**
     * 设备购置费合计
     */
    public void setPurchaseTotal(java.math.BigDecimal purchaseTotal) {
        this.purchaseTotal = purchaseTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    
     /**
      * 设计概算汇总子表
      */
     public List<EstimatesummarydetailVO> getEstimatesummarydetailEntities() {
        return estimatesummarydetailEntities;
     }

     /**
      * 设计概算汇总子表
      */
     public void setEstimatesummarydetailEntities(List<EstimatesummarydetailVO> estimatesummarydetailEntities) {
        this.estimatesummarydetailEntities = estimatesummarydetailEntities;
     }

    public List<RecordestimatesummaryVO> getRecordestimatesummaryVOList() {
        return recordestimatesummaryVOList;
    }

    public void setRecordestimatesummaryVOList(List<RecordestimatesummaryVO> recordestimatesummaryVOList) {
        this.recordestimatesummaryVOList = recordestimatesummaryVOList;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }
}
